Module rustsec::advisory [−][src]
Security advisories in the RustSec database
Re-exports
pub use self::affected::Affected;pub use self::category::Category;pub use self::date::Date;pub use self::id::Id;pub use self::informational::Informational;pub use self::keyword::Keyword;pub use self::linter::Linter;pub use self::metadata::Metadata;pub use self::versions::Versions;Modules
The [affected] subsection of an advisory: metadata specifying the scope
of impacted systems/functions/usages.
RustSec Vulnerability Categories
Advisory dates
Advisory identifiers
Informational advisories: ones which don’t represent an immediate security threat, but something users of a crate should be warned of/aware of
Advisory keywords
Advisory linter: ensure advisories are well-formed according to the currently valid set of fields.
Advisory information (i.e. the [advisory] section)
Support for parsing advisories from a Markdown file (a.k.a. “V3 advisory format”)
The [versions] subsection of an advisory.
Structs
RustSec Security Advisories
Enums
Qualitative Severity Rating Scale