Module binary_scanning

Module binary_scanning 

Recover dependency list from compiled Rust binaries

Most functions and types in this module only appear when the binary_scanning feature is enabled.

Enums

BinaryFormat
Formats of compiled executables that can be scanned
BinaryReportbinary-scanning
Dependencies recovered from scanning a compiled Rust executable

Functions

filter_report_by_binary_typebinary-scanning
Filters a Report to remove advisories not applicable to the given binary type.
load_deps_from_binarybinary-scanning
Load the dependency tree from a compiled Rust executable.