load_deps_from_binary

Function load_deps_from_binary 

pub fn load_deps_from_binary(
    file_contents: &[u8],
    audit_data_size_limit: Option<usize>,
) -> Result<(BinaryFormat, BinaryReport)>
Available on crate feature binary-scanning only.
Load the dependency tree from a compiled Rust executable.

Recovers the precise dependency list if the binary is built with cargo auditable. Failing that, recovers as many crates as possible from panic messages (using quitters).

If audit_data_size_limit is set to None, the limit defaults to 8MB.