logo
pub struct Query { /* private fields */ }
Queries against the RustSec database

Implementations

Create a new query.

This creates a “wildcard” query with no constraints. Use the various builder methods of this type to restrict which advisories match.

Note that this differs from Query::default(), which scopes the query to crates (i.e. Query::crate_scope).

When in doubt, use Query::default().

Create a new query which uses the default scope rules for crates:

  • Only Collection::Crates
  • Ignore withdrawn advisories
  • Ignore informational advisories

Set collection to query against

Provide a package and use all of its attributes as part of the query

Set package name to search for.

Set package version to search for

Set package source (e.g. registry) where this package is located

Set minimum severity threshold according to the CVSS Qualitative Severity Rating Scale.

Vulnerabilities without associated CVSS information will always match regardless of what this is set to.

Set target architecture

Set target operating system

Query for vulnerabilities occurring in a specific year.

Query for withdrawn advisories.

By default they will be omitted from query results.

Query for informational advisories. By default they will be omitted from query results.

Does this query match a given advisory?